@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2022 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -92,7 +92,7 @@ switch (get_request_var('action')) {
 	case 'ajax_hosts':
 		$sql_where = '';
 		if (get_request_var('site_id') > 0) {
-			$sql_where = 'site_id = ' . get_request_var('site_id');
+			$sql_where = 'site_id = ' . get_filter_request_var('site_id');
 		}
 
 		get_allowed_ajax_hosts(true, 'applyFilter', $sql_where);
@@ -101,7 +101,7 @@ switch (get_request_var('action')) {
 	case 'ajax_hosts_noany':
 		$sql_where = '';
 		if (get_request_var('site_id') > 0) {
-			$sql_where = 'site_id = ' . get_request_var('site_id');
+			$sql_where = 'site_id = ' . get_filter_request_var('site_id');
 		}
 
 		get_allowed_ajax_hosts(false, 'applyFilter', $sql_where);
@@ -249,7 +249,7 @@ function form_save() {
 		$return_array = create_complete_graph_from_template($graph_template_id, $host_id, $snmp_query_array, $suggested_values);
 
 		if ($return_array !== false) {
-			debug_log_insert('new_graphs', __('Created graph: %s', get_graph_title($return_array['local_graph_id'])));
+			debug_log_insert('new_graphs', __esc('Created graph: %s', get_graph_title($return_array['local_graph_id'])));
 
 			/* lastly push host-specific information to our data sources */
 			if (cacti_sizeof($return_array['local_data_id'])) { # we expect at least one data source associated
@@ -257,7 +257,7 @@ function form_save() {
 					push_out_host($host_id, $item);
 				}
 			} else {
-				debug_log_insert('new_graphs', __('ERROR: No Data Source associated. Check Template'));
+				debug_log_insert('new_graphs', __esc('ERROR: No Data Source associated. Check Template'));
 			}
 		}
 
@@ -1533,6 +1533,7 @@ function graph_edit() {
 						if (!empty($graph['graph_template_id'])) {
 							?><span class='linkMarker'>*</span><a class='hyperLink' href='<?php print html_escape('graph_templates.php?action=template_edit&id=' . (isset($graph['graph_template_id']) ? $graph['graph_template_id'] : '0'));?>'><?php print __('Edit Graph Template.');?></a><br><?php
 						}
+
 						if (cacti_sizeof($data_sources)) {
 							foreach($data_sources as $ds) {
 								$name = db_fetch_cell_prepared('SELECT name_cache
@@ -1540,12 +1541,14 @@ function graph_edit() {
 									WHERE local_data_id = ?',
 									array($ds['local_data_id']));
 
-							?><span class='linkMarker'>*</span><a class='hyperLink' href='<?php print html_escape('data_sources.php?action=ds_edit&id=' . $ds['local_data_id']);?>'><?php print __('Edit Data Source: \'%s\'.', $name);?></a><br><?php
+								?><span class='linkMarker'>*</span><a class='hyperLink' href='<?php print html_escape('data_sources.php?action=ds_edit&id=' . $ds['local_data_id']);?>'><?php print __esc('Edit Data Source: \'%s\'.', $name);?></a><br><?php
 							}
 						}
+
 						if (!isempty_request_var('host_id') || !empty($host_id)) {
 							?><span class='linkMarker'>*</span><a class='hyperLink' href='<?php print html_escape('host.php?action=edit&id=' . ($host_id > 0 ? $host_id : get_request_var('host_id')));?>'><?php print __('Edit Device.');?></a><br><?php
 						}
+
 						if ($locked) {
 							?><span class='linkMarker'>*</span><a href='#' class='hyperLink' id='unlockid'><?php print __('Unlock Graph.');?></a><?php
 						} else {
@@ -2152,6 +2155,8 @@ function graph_management() {
 			ON gl.id = gti.local_graph_id
 			LEFT JOIN data_template_rrd AS dtr
 			ON dtr.id = gti.task_item_id
+			INNER JOIN data_local AS dl
+			ON dl.id = dtr.local_data_id
 			LEFT JOIN host AS h
 			ON h.id = gl.host_id
 			WHERE graph_type_id IN (4,5,6,7,8,20)
@@ -2162,7 +2167,7 @@ function graph_management() {
 				ON c.id = ci.cdef_id
 				WHERE (ci.type = 4 OR (ci.type = 6 AND value LIKE '%DATA_SOURCE%'))
 			)
-			AND (dtr.id IS NULL OR (gl.snmp_query_id > 0 AND gl.snmp_index = ''))
+			AND (dl.orphan = 1 OR dtr.id IS NULL OR (gl.snmp_query_id > 0 AND gl.snmp_index = ''))
 			$sql_where2
 		) AS dtr
 		ON gl.id = dtr.local_graph_id";
