@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -26,7 +26,7 @@
      their actual values
    @arg $form_array - an array that contains all of the information needed to draw
      the html form. see the arrays contained in include/global_settings.php
-     for the extact syntax of this array
+     for the exact syntax of this array
    @arg $arg1 - an array that represents the |arg1:| variable (see
      include/global_form.php for more details)
    @arg $arg2 - an array that represents the |arg2:| variable (see
@@ -51,7 +51,7 @@ function inject_form_variables(&$form_array, $arg1 = array(), $arg2 = array(), $
 				} elseif (isset($field_array[$field_to_check]) && !is_array($field_array[$field_to_check])) {
 					$count = 0;
 
-					/* loop through the $field_to_check and replace upto three times
+					/* loop through the $field_to_check and replace up to three times
 					 * for each arg1:arg2:arg3 variables.
 					 */
 					while (true) {
@@ -76,7 +76,7 @@ function inject_form_variables(&$form_array, $arg1 = array(), $arg2 = array(), $
 								}
 							} else {
 								/* copy the value down from the array/key specified in the variable
-								 * replace upto three times for arg1:arg2:arg3 variables
+								 * replace up to three times for arg1:arg2:arg3 variables
 								 */
 								if (isset($$matches1)) {
 									if (is_array($$matches1)) {
@@ -261,21 +261,6 @@ function form_end_row() {
 	print "</tr>\n";
 }
 
-/* form_confirm_buttons - provides confirm buttons in the gui
-   @arg $message - the value of the HTML checkbox */
-function form_confim_buttons($post_variable, $item_array, $save_message, $return = false) {
-	print "<tr>
-		<td class='saveRow'>
-			<input type='hidden' name='action' value='actions'>
-			<input type='hidden' name='selected_items' value='" . (isset($item_array) ? serialize($item_array) : '') . "'>
-			<input type='hidden' name='drp_action' value='" . $post_variable . "'>" . ($return ? "
-			<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>
-			":"
-			<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') ."' title='$save_message'>") . "
-		</td>
-	</tr>\n";
-}
-
 /* html_boolean - returns the boolean equivalent of an HTML checkbox value
    @arg $html_boolean - the value of the HTML checkbox
    @returns - true or false based on the value of the HTML checkbox */
@@ -480,7 +465,7 @@ function get_filter_request_var($name, $filter = FILTER_VALIDATE_INT, $options =
 				}
 			} elseif ($filter == FILTER_VALIDATE_IS_NUMERIC_LIST) {
 				$valid = true;
-				$values = preg_split('/,/', $_REQUEST[$name], NULL, PREG_SPLIT_NO_EMPTY);
+				$values = preg_split('/,/', $_REQUEST[$name], -1, PREG_SPLIT_NO_EMPTY);
 				foreach($values AS $number) {
 					if (!is_numeric($number)) {
 						$valid = false;
@@ -700,7 +685,7 @@ function validate_store_request_vars($filters, $sess_prefix = '') {
 					}
 				} elseif ($options['filter'] == FILTER_VALIDATE_IS_NUMERIC_LIST) {
 					$valid = true;
-					$values = preg_split('/,/', $_REQUEST[$variable], NULL, PREG_SPLIT_NO_EMPTY);
+					$values = preg_split('/,/', $_REQUEST[$variable], -1, PREG_SPLIT_NO_EMPTY);
 					foreach($values AS $number) {
 						if (!is_numeric($number)) {
 							$valid = false;
@@ -872,6 +857,19 @@ function validate_is_regex($regex) {
 		return true;
 	}
 
+	/**
+	 * Prevent exploits from encoded Regular expressions that can cause
+	 * injections in MariaDB and MySQL.  We do this by limiting the
+	 * length of the regular expression to 50 bytes or less.
+	 */
+	if (strlen($regex) > 50) {
+		return __('Cacti regular expressions are limited to 50 characters only for security reasons.');
+	}
+
+	if (strpos($regex, ';') !== false) {
+		return __('Cacti regular expressions can not includes the semi-color character.');
+	}
+
 	restore_error_handler();
 
 	$track_errors = ini_get('track_errors');
@@ -1086,7 +1084,7 @@ function get_page_list($current_page, $pages_per_screen, $rows_per_page, $total_
 	if ($return_to != '') {
 		$url_page_select .= "<script type='text/javascript'>function goto$page_var(pageNo) { if (typeof url_graph === 'function') { var url_add=url_graph('') } else { var url_add=''; }; $.get('" . sanitize_uri($url) . "header=false&" . $page_var . "='+pageNo+url_add).done(function(data) { $('#$return_to').html(data); applySkin(); }); }</script>";
 	} else {
-		$url_page_select .= "<script type='text/javascript'>function goto${page_var}(pageNo) { if (typeof url_graph === 'function') { var url_add=url_graph('') } else { var url_add=''; }; document.location='$url$page_var='+pageNo+url_add }</script>";
+		$url_page_select .= "<script type='text/javascript'>function goto{$page_var}(pageNo) { if (typeof url_graph === 'function') { var url_add=url_graph('') } else { var url_add=''; }; document.location='$url$page_var='+pageNo+url_add }</script>";
 	}
 
 	return $url_page_select;
