@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2022 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  | Portions Copyright (C) 2010 Boris Lytochkin, Sponsored by Yandex LLC    |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
@@ -442,6 +442,14 @@ function cacti_snmp_session_walk($session, $oid, $dummy = false, $max_repetition
 		return array();
 	}
 
+	if (is_array($oid)) {
+		foreach($oid as $index => $o) {
+			$oid[$index] = trim($o);
+		}
+	} else {
+		$oid = trim($oid);
+	}
+
 	$session->value_output_format = $value_output_format;
 
 	if ($non_repeaters === NULL) {
@@ -457,7 +465,7 @@ function cacti_snmp_session_walk($session, $oid, $dummy = false, $max_repetition
 	}
 
 	try {
-		$out = @$session->walk(trim($oid), false, $max_repetitions, $non_repeaters);
+		$out = @$session->walk($oid, false, $max_repetitions, $non_repeaters);
 	} catch (Exception $e) {
 		$out = false;
 	}
@@ -478,8 +486,16 @@ function cacti_snmp_session_walk($session, $oid, $dummy = false, $max_repetition
 
 	if (cacti_sizeof($out)) {
 		foreach($out as $oid => $value){
-			$out[$oid] = format_snmp_string($value, false, $value_output_format);
+			if (is_array($value)) {
+				foreach($value as $index => $sval) {
+					$out[$oid][$index] = format_snmp_string($sval, false, $value_output_format);
+				}
+			} elseif ($out[$oid] !== false) {
+				$out[$oid] = format_snmp_string($value, false, $value_output_format);
+			}
 		}
+	} else {
+		$out = format_snmp_string($oid, false, $value_output_format);
 	}
 
 	return $out;
@@ -491,10 +507,16 @@ function cacti_snmp_session_get($session, $oid, $strip_alpha = false) {
 	if (is_array($oid) && cacti_sizeof($oid) == 0) {
 		cacti_log('Empty OID!', false);
 		return array();
+	} elseif (is_array($oid)) {
+		foreach($oid as $index => $o) {
+			$oid[$index] = trim($o);
+		}
+	} else {
+		$oid = trim($oid);
 	}
 
 	try {
-		$out = @$session->get(trim($oid));
+		$out = @$session->get($oid);
 	} catch (Exception $e) {
 		$out = false;
 	}
@@ -507,6 +529,7 @@ function cacti_snmp_session_get($session, $oid, $strip_alpha = false) {
 		if ($session->getErrno() == SNMP::ERRNO_TIMEOUT) {
 			cacti_log('WARNING: SNMP Error:\'Timeout (' . round($info['timeout']/1000,0) . " ms)', Device:'" . $info['hostname'] . "', OID:'$oid'", false, 'SNMP', POLLER_VERBOSITY_HIGH);
 		}
+
 		return false;
 	}
 
@@ -528,8 +551,16 @@ function cacti_snmp_session_getnext($session, $oid) {
 		return array();
 	}
 
+	if (is_array($oid)) {
+		foreach($oid as $index => $o) {
+			$oid[$index] = trim($o);
+		}
+	} else {
+		$oid = trim($oid);
+	}
+
 	try {
-		$out = @$session->getnext(trim($oid));
+		$out = @$session->getnext($oid);
 	} catch (Exception $e) {
 		$out = false;
 	}
@@ -900,16 +931,16 @@ function snmp_escape_string($string) {
 	if (! defined('SNMP_ESCAPE_CHARACTER')) {
 		if ($config['cacti_server_os'] == 'win32') {
 			define('SNMP_ESCAPE_CHARACTER', '"');
+
+			if (substr_count($string, SNMP_ESCAPE_CHARACTER)) {
+				$string = str_replace(SNMP_ESCAPE_CHARACTER, "\\" . SNMP_ESCAPE_CHARACTER, $string);
+			}
+
+			return SNMP_ESCAPE_CHARACTER . $string . SNMP_ESCAPE_CHARACTER;
 		} else {
-			define('SNMP_ESCAPE_CHARACTER', "'");
+			return cacti_escapeshellarg($string);
 		}
 	}
-
-	if (substr_count($string, SNMP_ESCAPE_CHARACTER)) {
-		$string = str_replace(SNMP_ESCAPE_CHARACTER, "\\" . SNMP_ESCAPE_CHARACTER, $string);
-	}
-
-	return SNMP_ESCAPE_CHARACTER . $string . SNMP_ESCAPE_CHARACTER;
 }
 
 function snmp_get_method($type = 'walk', $version = 1, $context = '', $engineid = '',
