@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -29,6 +29,11 @@ include_once($config['library_path'] . '/html_reports.php');
 include_once($config['library_path'] . '/timespan_settings.php');
 
 get_filter_request_var('id');
+get_filter_request_var('tree_id');
+get_filter_request_var('site_id');
+get_filter_request_var('host_id');
+get_filter_request_var('host_template_id');
+get_filter_request_var('graph_template_id');
 get_filter_request_var('tab', FILTER_CALLBACK, array('options' => 'sanitize_search_string'));
 
 /* set a longer execution time for large reports */
@@ -43,7 +48,7 @@ switch (get_request_var('action')) {
 
 		break;
 	case 'send':
-		get_filter_request_var('id');
+		get_request_var('id');
 
 		reports_send(get_request_var('id'));
 
@@ -52,28 +57,95 @@ switch (get_request_var('action')) {
 	case 'ajax_dnd':
 		reports_item_dnd();
 
-		header('Location: reports_admin.php?action=edit&header=false&tab=items&id=' . get_request_var('id'));
+		header('Location: reports_admin.php?action=edit&tab=items&id=' . get_request_var('id'));
 		break;
+	case 'setvar':
+		$changed = reports_item_validate();
+
+		print $changed;
+
+		break;
+	case 'ajax_get_branches':
+		print reports_get_branch_select(get_request_var('tree_id'));
+
+		break;
+	case 'ajax_hosts':
+		reports_item_validate();
+
+		$sql_where = '';
+		if (get_request_var('site_id') > 0) {
+			$sql_where .= ($sql_where != '' ? ' AND ':'') . 'h.site_id = ' . get_request_var('site_id');
+		}
+
+		if (get_request_var('host_template_id') > 0) {
+			$sql_where .= ($sql_where != '' ? ' AND ':'') . 'h.host_template_id = ' . get_request_var('host_template_id');
+		}
+
+		get_allowed_ajax_hosts(true, 'applyFilter', $sql_where);
+
+        break;
+	case 'ajax_graphs':
+		reports_item_validate();
+
+		$sql_where = '';
+		if (get_request_var('site_id') > 0) {
+			$sql_where .= ($sql_where != '' ? ' AND ':'') . 'h.site_id = ' . get_request_var('site_id');
+		}
+
+		if (get_request_var('host_id') > 0) {
+			$sql_where .= ($sql_where != '' ? ' AND ':'') . 'gl.host_id = ' . get_request_var('host_id');
+		}
+
+		if (get_request_var('graph_template_id') > 0) {
+			$sql_where .= ($sql_where != '' ? ' AND ':'') . 'gl.graph_template_id = ' . get_request_var('graph_template_id');
+		}
+
+		if (get_request_var('host_template_id') > 0) {
+			$sql_where .= ($sql_where != '' ? ' AND ':'') . 'h.host_template_id = ' . get_request_var('host_template_id');
+		}
+
+		get_allowed_ajax_graphs($sql_where);
+
+        break;
+	case 'ajax_graph_template':
+		reports_item_validate();
+
+		$sql_where = '';
+		if (get_request_var('site_id') > 0) {
+			$sql_where .= ($sql_where != '' ? ' AND ':'') . 'h.site_id = ' . get_request_var('site_id');
+		}
+
+		if (get_request_var('host_id') > 0) {
+			$sql_where .= ($sql_where != '' ? ' AND ':'') . 'h.id = ' . get_request_var('host_id');
+		}
+
+		if (get_request_var('host_template_id') > 0) {
+			$sql_where .= ($sql_where != '' ? ' AND ':'') . 'h.host_template_id = ' . get_request_var('host_template_id');
+		}
+
+		get_allowed_ajax_graph_templates(true, true, $sql_where);
+
+        break;
 	case 'actions':
 		reports_form_actions();
 
 		break;
 	case 'item_movedown':
-		get_filter_request_var('id');
+		get_request_var('id');
 
 		reports_item_movedown();
 
 		header('Location: reports_admin.php?action=edit&tab=items&id=' . get_request_var('id'));
 		break;
 	case 'item_moveup':
-		get_filter_request_var('id');
+		get_request_var('id');
 
 		reports_item_moveup();
 
 		header('Location: reports_admin.php?action=edit&tab=items&id=' . get_request_var('id'));
 		break;
 	case 'item_remove':
-		get_filter_request_var('id');
+		get_request_var('id');
 
 		reports_item_remove();
 
